@@ -497,9 +497,12 @@ static l_Setting get_setting(SettingsID settingId)
     case SettingsID::KeyBinding_Fullscreen:
         setting = {SETTING_SECTION_KEYBIND, "Fullscreen", std::string("Alt+Return")};
         break;
-    case SettingsID::Keybinding_ViewLog:
+    case SettingsID::KeyBinding_ViewLog:
         setting = {SETTING_SECTION_KEYBIND, "ViewLog", std::string("Ctrl+Alt+L")};
         break;
+    case SettingsID::KeyBinding_ViewSearch:
+        setting = {SETTING_SECTION_KEYBIND, "ViewSearch", std::string("Ctrl+F")};
+        break;
     case SettingsID::KeyBinding_GraphicsSettings:
         setting = {SETTING_SECTION_KEYBIND, "GraphicsSettings", std::string("Ctrl+G")};
         break;
@@ -538,7 +541,7 @@ static l_Setting get_setting(SettingsID settingId)
         setting = {SETTING_SECTION_ROMBROWSER, "Recursive", true};
         break;
     case SettingsID::RomBrowser_MaxItems:
-        setting = {SETTING_SECTION_ROMBROWSER, "MaxItems", 1024};
+        setting = {SETTING_SECTION_ROMBROWSER, "MaxItems", 2048};
         break;
     case SettingsID::RomBrowser_ColumnVisibility:
         setting = {SETTING_SECTION_ROMBROWSER, "ColumnVisibility", std::string("1;1;1;0;0;0;0;0;0;")};
@@ -1360,7 +1363,7 @@ static void config_listsections_callback(void*, const char* section)
     l_sectionList.emplace_back(std::string(section));
 }
 
-static bool config_section_exists(std::string section)
+static bool config_section_exists(const std::string& section)
 {
     std::string error;
     m64p_error ret;
@@ -1384,7 +1387,7 @@ static bool config_section_exists(std::string section)
     return std::find(l_sectionList.begin(), l_sectionList.end(), section) != l_sectionList.end();
 }
 
-static bool config_section_open(std::string section)
+static bool config_section_open(const std::string& section)
 {
     std::string error;
     m64p_error ret;
@@ -1417,7 +1420,7 @@ static void config_listkeys_callback(void*, const char* key, m64p_type)
     l_keyList.push_back(std::string(key));
 }
 
-static bool config_key_exists(std::string section, std::string key)
+static bool config_key_exists(const std::string& section, const std::string& key)
 {
     std::string error;
     m64p_error ret;
@@ -1446,7 +1449,7 @@ static bool config_key_exists(std::string section, std::string key)
     return std::find(l_keyList.begin(), l_keyList.end(), key) != l_keyList.end();
 }
 
-static bool config_option_set(std::string section, std::string key, m64p_type type, void *value)
+static bool config_option_set(const std::string& section, const std::string& key, m64p_type type, void *value)
 {
     std::string error;
     m64p_error ret;
@@ -1472,7 +1475,7 @@ static bool config_option_set(std::string section, std::string key, m64p_type ty
     return ret == M64ERR_SUCCESS;
 }
 
-static bool config_option_get(std::string section, std::string key, m64p_type type, void *value, int size)
+static bool config_option_get(const std::string& section, const std::string& key, m64p_type type, void *value, int size)
 {
     std::string error;
     m64p_error ret;
@@ -1505,7 +1508,7 @@ static bool config_option_get(std::string section, std::string key, m64p_type ty
     return ret == M64ERR_SUCCESS;
 }
 
-static bool config_option_default_set(std::string section, std::string key, m64p_type type, void *value, const char* description)
+static bool config_option_default_set(const std::string& section, const std::string& key, m64p_type type, void *value, const char* description)
 {
     std::string error;
     m64p_error ret;
@@ -1573,7 +1576,7 @@ static bool int_list_to_string(const std::vector<int>& intList, std::string& str
     return true;
 }
 
-static bool string_to_int_list(std::string string, std::vector<int>& intList)
+static bool string_to_int_list(const std::string& string, std::vector<int>& intList)
 {
     std::string error;
 
@@ -1628,7 +1631,7 @@ static bool string_list_to_string(const std::vector<std::string>& stringList, st
     return true;
 }
 
-static bool string_to_string_list(std::string string, std::vector<std::string>& stringList)
+static bool string_to_string_list(const std::string& string, std::vector<std::string>& stringList)
 {
     std::string error;
 
