@@ -166,7 +166,8 @@ enum class SettingsID
     KeyBinding_SaveStateSlot8,
     KeyBinding_SaveStateSlot9,
     KeyBinding_Fullscreen,
-    Keybinding_ViewLog,
+    KeyBinding_ViewLog,
+    KeyBinding_ViewSearch,
     KeyBinding_GraphicsSettings,
     KeyBinding_AudioSettings,
     KeyBinding_RspSettings,
