@@ -1057,8 +1057,9 @@ void SettingsDialog::commonHotkeySettings(SettingsDialogAction action)
     std::vector<keybinding> keybindings_View =
     {
         { this->fullscreenKeyButton, SettingsID::KeyBinding_Fullscreen },
-        { this->logKeyButton, SettingsID::Keybinding_ViewLog },
-        { this->refreshRomListKeyButton, SettingsID::KeyBinding_RefreshROMList }
+        { this->logKeyButton, SettingsID::KeyBinding_ViewLog },
+        { this->refreshRomListKeyButton, SettingsID::KeyBinding_RefreshROMList },
+        { this->searchKeyButton, SettingsID::KeyBinding_ViewSearch }
     };
 
 
